==> 2.0.3.tar.gz: lib/src/loader.dart <==
part of '../loader_plus.dart';

typedef LoaderCallback<T> = Future<T> Function();
typedef WidgetValueBuilder<T> = Widget Function(BuildContext context, T value);
typedef WidgetValueBuilderUseRefresh<T> = Widget Function(BuildContext context, T value,LoaderState<T> state);

class Loader<T> extends StatefulWidget {
  final bool autoReload;
  final LoaderCallback<T> load;
  final WidgetValueBuilder<T>? builder;
  final WidgetValueBuilderUseRefresh<T>? builderUseRefresh;
  final Widget? loadingWidget;
  final Widget Function(Object? error)? errorBuilder;

  const Loader({
    Key? key,
    required this.load,
    this.autoReload = true,
    this.builder,
    this.loadingWidget,
    this.errorBuilder,
    this.builderUseRefresh,
  }) : super(key: key);

  @override
  LoaderState<T> createState() => LoaderState<T>();
}

class LoaderState<T> extends State<Loader<T>> {

  late final runOnce = AsyncMemoizer<T>().runOnce(() => widget.load());

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<T>(
      future: runOnce,
      builder: (context, snapshot) {
        final data = snapshot.data;
        if (snapshot.hasData && data != null) {

          return widget.builderUseRefresh?.call(context,data,this) ?? (widget.builder?.call(context, data) ?? const SizedBox.shrink());
        } else if (snapshot.hasError) {
          return widget.errorBuilder?.call(snapshot.error) ??
              Text('${snapshot.error}');
        } else if (snapshot.connectionState == ConnectionState.waiting) {
          return widget.loadingWidget ?? const SizedBox.shrink();
        } else {
          return const SizedBox.shrink();
        }
      },
    );
  }
}

==> 2.0.4.tar.gz: lib/src/loader.dart <==
part of '../loader_plus.dart';

typedef LoaderCallback<T> = Future<T> Function();
typedef WidgetValueBuilder<T> = Widget Function(BuildContext context, T value);
typedef WidgetValueBuilderUseRefresh<T> = Widget Function(BuildContext context, T value, LoaderState<T> state);

class Loader<T> extends StatefulWidget {
  final bool autoReload;
  final LoaderCallback<T> load;
  final WidgetValueBuilder<T>? builder;
  final WidgetValueBuilderUseRefresh<T>? builderUseRefresh;
  final Widget? loadingWidget;
  final Widget Function(Object? error)? errorBuilder;

  const Loader({
    Key? key,
    required this.load,
    this.autoReload = true,
    this.builder,
    this.loadingWidget,
    this.errorBuilder,
    this.builderUseRefresh,
  }) : super(key: key);

  @override
  LoaderState<T> createState() => LoaderState<T>();
}

class LoaderState<T> extends State<Loader<T>> {
  late final runOnce = AsyncMemoizer<T>().runOnce(() => widget.load());

  void reBuilder() {
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder<T>(
      future: runOnce,
      builder: (context, snapshot) {
        final data = snapshot.data;
        if (snapshot.hasData && data != null) {
          return widget.builderUseRefresh?.call(context, data, this) ?? (widget.builder?.call(context, data) ?? const SizedBox.shrink());
        } else if (snapshot.hasError) {
          return widget.errorBuilder?.call(snapshot.error) ?? Text('${snapshot.error}');
        } else if (snapshot.connectionState == ConnectionState.waiting) {
          return widget.loadingWidget ?? const SizedBox.shrink();
        } else {
          return const SizedBox.shrink();
        }
      },
    );
  }
}
